# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_documentdb.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&azure/azure_microsoft_documentdb.proto\x12&oak9.tython.azure.microsoft_documentdb\x1a\x13shared/shared.proto\"\x8f\x07\n\x14Microsoft_DocumentDB\x12S\n\x11\x64\x61tabase_accounts\x18\x01 \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_documentdb.DatabaseAccounts\x12y\n%database_accounts_cassandra_keyspaces\x18\x02 \x03(\x0b\x32J.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsCassandraKeyspaces\x12\x86\x01\n,database_accounts_cassandra_keyspaces_tables\x18\x03 \x03(\x0b\x32P.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsCassandraKeyspacesTables\x12\x82\x01\n*database_accounts_gremlin_databases_graphs\x18\x04 \x03(\x0b\x32N.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsGremlinDatabasesGraphs\x12m\n\x1f\x64\x61tabase_accounts_sql_databases\x18\x05 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlDatabases\x12\x82\x01\n*database_accounts_sql_databases_containers\x18\x06 \x03(\x0b\x32N.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlDatabasesContainers\x12\xa4\x01\n<database_accounts_sql_databases_containers_stored_procedures\x18\x07 \x03(\x0b\x32^.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlDatabasesContainersStoredProcedures\"\xc2\x03\n(DatabaseAccountsTablesThroughputSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12T\n\x08resource\x18\x05 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_documentdb.ThroughputSettingsResource\x12h\n\x04tags\x18\x06 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsTablesThroughputSettings.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe8\x04\n\x16\x44\x61tabaseAccountsTables\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12L\n\x07options\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_documentdb.CreateUpdateOptions\x12G\n\x08resource\x18\x06 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_documentdb.TableResource\x12V\n\x04tags\x18\x07 \x03(\x0b\x32H.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsTables.TagsEntry\x12\x86\x01\n,database_accounts_tables_throughput_settings\x18\x08 \x03(\x0b\x32P.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsTablesThroughputSettings\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1b\n\rTableResource\x12\n\n\x02id\x18\x01 \x01(\t\"\xf0\x01\n\"DatabaseAccountsSqlRoleDefinitions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x61ssignable_scopes\x18\x03 \x03(\t\x12G\n\x0bpermissions\x18\x04 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_documentdb.Permission\x12\x11\n\trole_name\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\"<\n\nPermission\x12\x14\n\x0c\x64\x61ta_actions\x18\x01 \x03(\t\x12\x18\n\x10not_data_actions\x18\x02 \x03(\t\"\xac\x01\n\"DatabaseAccountsSqlRoleAssignments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0cprincipal_id\x18\x03 \x01(\t\x12\x1a\n\x12role_definition_id\x18\x04 \x01(\t\x12\r\n\x05scope\x18\x05 \x01(\t\"\xce\x03\n.DatabaseAccountsSqlDatabasesThroughputSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12T\n\x08resource\x18\x05 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_documentdb.ThroughputSettingsResource\x12n\n\x04tags\x18\x06 \x03(\x0b\x32`.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlDatabasesThroughputSettings.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb8\x04\n:DatabaseAccountsSqlDatabasesContainersUserDefinedFunctions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12L\n\x07options\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_documentdb.CreateUpdateOptions\x12X\n\x08resource\x18\x06 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_documentdb.SqlUserDefinedFunctionResource\x12z\n\x04tags\x18\x07 \x03(\x0b\x32l.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlDatabasesContainersUserDefinedFunctions.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x1eSqlUserDefinedFunctionResource\x12\x0c\n\x04\x62ody\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"\x94\x04\n.DatabaseAccountsSqlDatabasesContainersTriggers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12L\n\x07options\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_documentdb.CreateUpdateOptions\x12L\n\x08resource\x18\x06 \x01(\x0b\x32:.oak9.tython.azure.microsoft_documentdb.SqlTriggerResource\x12n\n\x04tags\x18\x07 \x03(\x0b\x32`.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlDatabasesContainersTriggers.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"_\n\x12SqlTriggerResource\x12\x0c\n\x04\x62ody\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x19\n\x11trigger_operation\x18\x03 \x01(\t\x12\x14\n\x0ctrigger_type\x18\x04 \x01(\t\"\xe2\x03\n8DatabaseAccountsSqlDatabasesContainersThroughputSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12T\n\x08resource\x18\x05 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_documentdb.ThroughputSettingsResource\x12x\n\x04tags\x18\x06 \x03(\x0b\x32j.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlDatabasesContainersThroughputSettings.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xac\x04\n6DatabaseAccountsSqlDatabasesContainersStoredProcedures\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12L\n\x07options\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_documentdb.CreateUpdateOptions\x12T\n\x08resource\x18\x06 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_documentdb.SqlStoredProcedureResource\x12v\n\x04tags\x18\x07 \x03(\x0b\x32h.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlDatabasesContainersStoredProcedures.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\x1aSqlStoredProcedureResource\x12\x0c\n\x04\x62ody\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"\xf7\x07\n&DatabaseAccountsSqlDatabasesContainers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12L\n\x07options\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_documentdb.CreateUpdateOptions\x12N\n\x08resource\x18\x06 \x01(\x0b\x32<.oak9.tython.azure.microsoft_documentdb.SqlContainerResource\x12\x66\n\x04tags\x18\x07 \x03(\x0b\x32X.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlDatabasesContainers.TagsEntry\x12\xa8\x01\n>database_accounts_sql_databases_containers_throughput_settings\x18\x08 \x03(\x0b\x32`.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlDatabasesContainersThroughputSettings\x12\xad\x01\nAdatabase_accounts_sql_databases_containers_user_defined_functions\x18\t \x03(\x0b\x32\x62.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlDatabasesContainersUserDefinedFunctions\x12\x93\x01\n3database_accounts_sql_databases_containers_triggers\x18\n \x03(\x0b\x32V.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlDatabasesContainersTriggers\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb8\x03\n\x14SqlContainerResource\x12\x1e\n\x16\x61nalytical_storage_ttl\x18\x01 \x01(\x05\x12\x64\n\x1a\x63onflict_resolution_policy\x18\x02 \x01(\x0b\x32@.oak9.tython.azure.microsoft_documentdb.ConflictResolutionPolicy\x12\x13\n\x0b\x64\x65\x66\x61ult_ttl\x18\x03 \x01(\x05\x12\n\n\x02id\x18\x04 \x01(\t\x12O\n\x0findexing_policy\x18\x05 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_documentdb.IndexingPolicy\x12T\n\rpartition_key\x18\x06 \x01(\x0b\x32=.oak9.tython.azure.microsoft_documentdb.ContainerPartitionKey\x12R\n\x11unique_key_policy\x18\x07 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_documentdb.UniqueKeyPolicy\"\xd0\x01\n0DatabaseAccountsSqlDatabasesClientEncryptionKeys\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12U\n\x08resource\x18\x03 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_documentdb.ClientEncryptionKeyResource\"\xc0\x01\n\x1b\x43lientEncryptionKeyResource\x12\x1c\n\x14\x65ncryption_algorithm\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12R\n\x11key_wrap_metadata\x18\x03 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_documentdb.KeyWrapMetadata\x12#\n\x1bwrapped_data_encryption_key\x18\x04 \x01(\t\"O\n\x0fKeyWrapMetadata\x12\x11\n\talgorithm\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\"\xa2\x06\n\x1c\x44\x61tabaseAccountsSqlDatabases\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12L\n\x07options\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_documentdb.CreateUpdateOptions\x12M\n\x08resource\x18\x06 \x01(\x0b\x32;.oak9.tython.azure.microsoft_documentdb.SqlDatabaseResource\x12\\\n\x04tags\x18\x07 \x03(\x0b\x32N.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlDatabases.TagsEntry\x12\x93\x01\n3database_accounts_sql_databases_throughput_settings\x18\x08 \x03(\x0b\x32V.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlDatabasesThroughputSettings\x12\x98\x01\n6database_accounts_sql_databases_client_encryption_keys\x18\t \x03(\x0b\x32X.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlDatabasesClientEncryptionKeys\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"!\n\x13SqlDatabaseResource\x12\n\n\x02id\x18\x01 \x01(\t\"\xa6\x01\n\x18\x44\x61tabaseAccountsServices\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0einstance_count\x18\x03 \x01(\x05\x12\x15\n\rinstance_size\x18\x04 \x01(\t\x12\x14\n\x0cservice_type\x18\x05 \x01(\t\"\xff\x02\n*DatabaseAccountsPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08group_id\x18\x03 \x01(\t\x12Y\n\x10private_endpoint\x18\x04 \x01(\x0b\x32?.oak9.tython.azure.microsoft_documentdb.PrivateEndpointProperty\x12\x80\x01\n%private_link_service_connection_state\x18\x05 \x01(\x0b\x32Q.oak9.tython.azure.microsoft_documentdb.PrivateLinkServiceConnectionStateProperty\x12\x1a\n\x12provisioning_state\x18\x06 \x01(\t\"P\n)PrivateLinkServiceConnectionStateProperty\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\"%\n\x17PrivateEndpointProperty\x12\n\n\x02id\x18\x01 \x01(\t\"k\n\"DatabaseAccountsNotebookWorkspaces\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x91\x02\n&DatabaseAccountsMongodbUserDefinitions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x63ustom_data\x18\x03 \x01(\t\x12\x15\n\rdatabase_name\x18\x04 \x01(\t\x12\x12\n\nmechanisms\x18\x05 \x01(\t\x12\x10\n\x08password\x18\x06 \x01(\t\x12;\n\x05roles\x18\x07 \x03(\x0b\x32,.oak9.tython.azure.microsoft_documentdb.Role\x12\x11\n\tuser_name\x18\x08 \x01(\t\"\xab\x02\n&DatabaseAccountsMongodbRoleDefinitions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rdatabase_name\x18\x03 \x01(\t\x12\x45\n\nprivileges\x18\x04 \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_documentdb.Privilege\x12\x11\n\trole_name\x18\x05 \x01(\t\x12;\n\x05roles\x18\x06 \x03(\x0b\x32,.oak9.tython.azure.microsoft_documentdb.Role\x12\x0c\n\x04type\x18\x07 \x01(\t\" \n\x04Role\x12\n\n\x02\x64\x62\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\"i\n\tPrivilege\x12\x0f\n\x07\x61\x63tions\x18\x01 \x03(\t\x12K\n\x08resource\x18\x02 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_documentdb.PrivilegeResource\"3\n\x11PrivilegeResource\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\n\n\x02\x64\x62\x18\x02 \x01(\t\"\xd6\x03\n2DatabaseAccountsMongodbDatabasesThroughputSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12T\n\x08resource\x18\x05 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_documentdb.ThroughputSettingsResource\x12r\n\x04tags\x18\x06 \x03(\x0b\x32\x64.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsMongodbDatabasesThroughputSettings.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xec\x03\n=DatabaseAccountsMongodbDatabasesCollectionsThroughputSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12T\n\x08resource\x18\x05 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_documentdb.ThroughputSettingsResource\x12}\n\x04tags\x18\x06 \x03(\x0b\x32o.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsMongodbDatabasesCollectionsThroughputSettings.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xca\x05\n+DatabaseAccountsMongodbDatabasesCollections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12L\n\x07options\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_documentdb.CreateUpdateOptions\x12S\n\x08resource\x18\x06 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_documentdb.MongoDBCollectionResource\x12k\n\x04tags\x18\x07 \x03(\x0b\x32].oak9.tython.azure.microsoft_documentdb.DatabaseAccountsMongodbDatabasesCollections.TagsEntry\x12\xb2\x01\nCdatabase_accounts_mongodb_databases_collections_throughput_settings\x18\x08 \x03(\x0b\x32\x65.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsMongodbDatabasesCollectionsThroughputSettings\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa1\x02\n\x19MongoDBCollectionResource\x12\x1e\n\x16\x61nalytical_storage_ttl\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\t\x12\x43\n\x07indexes\x18\x03 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_documentdb.MongoIndex\x12\x62\n\tshard_key\x18\x04 \x03(\x0b\x32O.oak9.tython.azure.microsoft_documentdb.MongoDBCollectionResource.ShardKeyEntry\x1a/\n\rShardKeyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9d\x01\n\nMongoIndex\x12\x43\n\x03key\x18\x01 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_documentdb.MongoIndexKeys\x12J\n\x07options\x18\x02 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_documentdb.MongoIndexOptions\"A\n\x11MongoIndexOptions\x12\x1c\n\x14\x65xpire_after_seconds\x18\x01 \x01(\x05\x12\x0e\n\x06unique\x18\x02 \x01(\x08\"\x1e\n\x0eMongoIndexKeys\x12\x0c\n\x04keys\x18\x01 \x03(\t\"\xaa\x06\n DatabaseAccountsMongodbDatabases\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12L\n\x07options\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_documentdb.CreateUpdateOptions\x12Q\n\x08resource\x18\x06 \x01(\x0b\x32?.oak9.tython.azure.microsoft_documentdb.MongoDBDatabaseResource\x12`\n\x04tags\x18\x07 \x03(\x0b\x32R.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsMongodbDatabases.TagsEntry\x12\x9b\x01\n7database_accounts_mongodb_databases_throughput_settings\x18\x08 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsMongodbDatabasesThroughputSettings\x12\x8c\x01\n/database_accounts_mongodb_databases_collections\x18\t \x03(\x0b\x32S.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsMongodbDatabasesCollections\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"%\n\x17MongoDBDatabaseResource\x12\n\n\x02id\x18\x01 \x01(\t\"\xd6\x03\n2DatabaseAccountsGremlinDatabasesThroughputSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12T\n\x08resource\x18\x05 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_documentdb.ThroughputSettingsResource\x12r\n\x04tags\x18\x06 \x03(\x0b\x32\x64.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsGremlinDatabasesThroughputSettings.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe2\x03\n8DatabaseAccountsGremlinDatabasesGraphsThroughputSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12T\n\x08resource\x18\x05 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_documentdb.ThroughputSettingsResource\x12x\n\x04tags\x18\x06 \x03(\x0b\x32j.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsGremlinDatabasesGraphsThroughputSettings.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb1\x05\n&DatabaseAccountsGremlinDatabasesGraphs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12L\n\x07options\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_documentdb.CreateUpdateOptions\x12N\n\x08resource\x18\x06 \x01(\x0b\x32<.oak9.tython.azure.microsoft_documentdb.GremlinGraphResource\x12\x66\n\x04tags\x18\x07 \x03(\x0b\x32X.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsGremlinDatabasesGraphs.TagsEntry\x12\xa8\x01\n>database_accounts_gremlin_databases_graphs_throughput_settings\x18\x08 \x03(\x0b\x32`.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsGremlinDatabasesGraphsThroughputSettings\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x03\n\x14GremlinGraphResource\x12\x64\n\x1a\x63onflict_resolution_policy\x18\x01 \x01(\x0b\x32@.oak9.tython.azure.microsoft_documentdb.ConflictResolutionPolicy\x12\x13\n\x0b\x64\x65\x66\x61ult_ttl\x18\x02 \x01(\x05\x12\n\n\x02id\x18\x03 \x01(\t\x12O\n\x0findexing_policy\x18\x04 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_documentdb.IndexingPolicy\x12T\n\rpartition_key\x18\x05 \x01(\x0b\x32=.oak9.tython.azure.microsoft_documentdb.ContainerPartitionKey\x12R\n\x11unique_key_policy\x18\x06 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_documentdb.UniqueKeyPolicy\"Y\n\x0fUniqueKeyPolicy\x12\x46\n\x0bunique_keys\x18\x01 \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_documentdb.UniqueKey\"\x1a\n\tUniqueKey\x12\r\n\x05paths\x18\x01 \x03(\t\"E\n\x15\x43ontainerPartitionKey\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\r\n\x05paths\x18\x02 \x03(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\"\xc6\x03\n\x0eIndexingPolicy\x12\x11\n\tautomatic\x18\x01 \x01(\x08\x12g\n\x11\x63omposite_indexes\x18\x02 \x03(\x0b\x32L.oak9.tython.azure.microsoft_documentdb.IndexingPolicy.CompositeIndexesEntry\x12L\n\x0e\x65xcluded_paths\x18\x03 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_documentdb.ExcludedPath\x12L\n\x0eincluded_paths\x18\x04 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_documentdb.IncludedPath\x12\x15\n\rindexing_mode\x18\x05 \x01(\t\x12L\n\x0fspatial_indexes\x18\x06 \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_documentdb.SpatialSpec\x1a\x37\n\x15\x43ompositeIndexesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"*\n\x0bSpatialSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\r\n\x05types\x18\x02 \x03(\t\"^\n\x0cIncludedPath\x12@\n\x07indexes\x18\x01 \x03(\x0b\x32/.oak9.tython.azure.microsoft_documentdb.Indexes\x12\x0c\n\x04path\x18\x02 \x01(\t\"=\n\x07Indexes\x12\x11\n\tdata_type\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x11\n\tprecision\x18\x03 \x01(\x05\"\x1c\n\x0c\x45xcludedPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"q\n\x18\x43onflictResolutionPolicy\x12 \n\x18\x63onflict_resolution_path\x18\x01 \x01(\t\x12%\n\x1d\x63onflict_resolution_procedure\x18\x02 \x01(\t\x12\x0c\n\x04mode\x18\x03 \x01(\t\"\x9b\x05\n DatabaseAccountsGremlinDatabases\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12L\n\x07options\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_documentdb.CreateUpdateOptions\x12Q\n\x08resource\x18\x06 \x01(\x0b\x32?.oak9.tython.azure.microsoft_documentdb.GremlinDatabaseResource\x12`\n\x04tags\x18\x07 \x03(\x0b\x32R.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsGremlinDatabases.TagsEntry\x12\x9b\x01\n7database_accounts_gremlin_databases_throughput_settings\x18\x08 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsGremlinDatabasesThroughputSettings\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"%\n\x17GremlinDatabaseResource\x12\n\n\x02id\x18\x01 \x01(\t\"\xdf\x03\n\x16\x44\x61tabaseAccountsGraphs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12L\n\x07options\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_documentdb.CreateUpdateOptions\x12G\n\x08resource\x18\x06 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_documentdb.GraphResource\x12V\n\x04tags\x18\x07 \x03(\x0b\x32H.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsGraphs.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1b\n\rGraphResource\x12\n\n\x02id\x18\x01 \x01(\t\"\xac\x02\n DatabaseAccountsDataTransferJobs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12W\n\x0b\x64\x65stination\x18\x03 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_documentdb.DataTransferDataSourceSink\x12R\n\x06source\x18\x04 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_documentdb.DataTransferDataSourceSink\x12\x14\n\x0cworker_count\x18\x05 \x01(\x05\"*\n\x1a\x44\x61taTransferDataSourceSink\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xe4\x03\n9DatabaseAccountsCassandraKeyspacesViewsThroughputSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12T\n\x08resource\x18\x05 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_documentdb.ThroughputSettingsResource\x12y\n\x04tags\x18\x06 \x03(\x0b\x32k.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsCassandraKeyspacesViewsThroughputSettings.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x05\n\'DatabaseAccountsCassandraKeyspacesViews\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12L\n\x07options\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_documentdb.CreateUpdateOptions\x12O\n\x08resource\x18\x06 \x01(\x0b\x32=.oak9.tython.azure.microsoft_documentdb.CassandraViewResource\x12g\n\x04tags\x18\x07 \x03(\x0b\x32Y.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsCassandraKeyspacesViews.TagsEntry\x12\xaa\x01\n?database_accounts_cassandra_keyspaces_views_throughput_settings\x18\x08 \x03(\x0b\x32\x61.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsCassandraKeyspacesViewsThroughputSettings\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\x15\x43\x61ssandraViewResource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0fview_definition\x18\x02 \x01(\t\"\xda\x03\n4DatabaseAccountsCassandraKeyspacesThroughputSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12T\n\x08resource\x18\x05 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_documentdb.ThroughputSettingsResource\x12t\n\x04tags\x18\x06 \x03(\x0b\x32\x66.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsCassandraKeyspacesThroughputSettings.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe6\x03\n:DatabaseAccountsCassandraKeyspacesTablesThroughputSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12T\n\x08resource\x18\x05 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_documentdb.ThroughputSettingsResource\x12z\n\x04tags\x18\x06 \x03(\x0b\x32l.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsCassandraKeyspacesTablesThroughputSettings.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x01\n\x1aThroughputSettingsResource\x12]\n\x12\x61utoscale_settings\x18\x01 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_documentdb.AutoscaleSettingsResource\x12\x12\n\nthroughput\x18\x02 \x01(\x05\"\x93\x01\n\x19\x41utoscaleSettingsResource\x12^\n\x13\x61uto_upgrade_policy\x18\x01 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_documentdb.AutoUpgradePolicyResource\x12\x16\n\x0emax_throughput\x18\x02 \x01(\x05\"x\n\x19\x41utoUpgradePolicyResource\x12[\n\x11throughput_policy\x18\x01 \x01(\x0b\x32@.oak9.tython.azure.microsoft_documentdb.ThroughputPolicyResource\"I\n\x18ThroughputPolicyResource\x12\x19\n\x11increment_percent\x18\x01 \x01(\x05\x12\x12\n\nis_enabled\x18\x02 \x01(\x08\"\xbb\x05\n(DatabaseAccountsCassandraKeyspacesTables\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12L\n\x07options\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_documentdb.CreateUpdateOptions\x12P\n\x08resource\x18\x06 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.CassandraTableResource\x12h\n\x04tags\x18\x07 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsCassandraKeyspacesTables.TagsEntry\x12\xac\x01\n@database_accounts_cassandra_keyspaces_tables_throughput_settings\x18\x08 \x03(\x0b\x32\x62.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsCassandraKeyspacesTablesThroughputSettings\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa2\x01\n\x16\x43\x61ssandraTableResource\x12\x1e\n\x16\x61nalytical_storage_ttl\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x65\x66\x61ult_ttl\x18\x02 \x01(\x05\x12\n\n\x02id\x18\x03 \x01(\t\x12G\n\x06schema\x18\x04 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_documentdb.CassandraSchema\"\xf3\x01\n\x0f\x43\x61ssandraSchema\x12H\n\x0c\x63luster_keys\x18\x01 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_documentdb.ClusterKey\x12?\n\x07\x63olumns\x18\x02 \x03(\x0b\x32..oak9.tython.azure.microsoft_documentdb.Column\x12U\n\x0epartition_keys\x18\x03 \x03(\x0b\x32=.oak9.tython.azure.microsoft_documentdb.CassandraPartitionKey\"%\n\x15\x43\x61ssandraPartitionKey\x12\x0c\n\x04name\x18\x01 \x01(\t\"$\n\x06\x43olumn\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\",\n\nClusterKey\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08order_by\x18\x02 \x01(\t\"\xac\x06\n\"DatabaseAccountsCassandraKeyspaces\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12L\n\x07options\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_documentdb.CreateUpdateOptions\x12S\n\x08resource\x18\x06 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_documentdb.CassandraKeyspaceResource\x12\x62\n\x04tags\x18\x07 \x03(\x0b\x32T.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsCassandraKeyspaces.TagsEntry\x12\x9f\x01\n9database_accounts_cassandra_keyspaces_throughput_settings\x18\x08 \x03(\x0b\x32\\.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsCassandraKeyspacesThroughputSettings\x12\x84\x01\n+database_accounts_cassandra_keyspaces_views\x18\t \x03(\x0b\x32O.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsCassandraKeyspacesViews\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x19\x43\x61ssandraKeyspaceResource\x12\n\n\x02id\x18\x01 \x01(\t\"\x80\x01\n\x13\x43reateUpdateOptions\x12U\n\x12\x61utoscale_settings\x18\x01 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_documentdb.AutoscaleSettings\x12\x12\n\nthroughput\x18\x02 \x01(\x05\"+\n\x11\x41utoscaleSettings\x12\x16\n\x0emax_throughput\x18\x01 \x01(\x05\"\xf0\x19\n\x10\x44\x61tabaseAccounts\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x08identity\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12p\n analytical_storage_configuration\x18\x06 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_documentdb.AnalyticalStorageConfiguration\x12M\n\x0e\x61pi_properties\x18\x07 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_documentdb.ApiProperties\x12K\n\rbackup_policy\x18\x08 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_documentdb.BackupPolicy\x12H\n\x0c\x63\x61pabilities\x18\t \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_documentdb.Capability\x12\x42\n\x08\x63\x61pacity\x18\n \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_documentdb.Capacity\x12\x17\n\x0f\x63onnector_offer\x18\x0b \x01(\t\x12U\n\x12\x63onsistency_policy\x18\x0c \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_documentdb.ConsistencyPolicy\x12@\n\x04\x63ors\x18\r \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_documentdb.CorsPolicy\x12\x13\n\x0b\x63reate_mode\x18\x0e \x01(\t\x12#\n\x1b\x64\x61tabase_account_offer_type\x18\x0f \x01(\t\x12\x18\n\x10\x64\x65\x66\x61ult_identity\x18\x10 \x01(\t\x12^\n\x17\x64iagnostic_log_settings\x18\x11 \x01(\x0b\x32=.oak9.tython.azure.microsoft_documentdb.DiagnosticLogSettings\x12/\n\'disable_key_based_metadata_write_access\x18\x12 \x01(\x08\x12\x1a\n\x12\x64isable_local_auth\x18\x13 \x01(\x08\x12!\n\x19\x65nable_analytical_storage\x18\x14 \x01(\x08\x12!\n\x19\x65nable_automatic_failover\x18\x15 \x01(\x08\x12\"\n\x1a\x65nable_cassandra_connector\x18\x16 \x01(\x08\x12\x18\n\x10\x65nable_free_tier\x18\x17 \x01(\x08\x12!\n\x19\x65nable_materialized_views\x18\x18 \x01(\x08\x12\'\n\x1f\x65nable_multiple_write_locations\x18\x19 \x01(\x08\x12J\n\x08ip_rules\x18\x1a \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_documentdb.IpAddressOrRange\x12)\n!is_virtual_network_filter_enabled\x18\x1b \x01(\x08\x12\x19\n\x11key_vault_key_uri\x18\x1c \x01(\t\x12\x43\n\tlocations\x18\x1d \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_documentdb.Location\x12\x1a\n\x12network_acl_bypass\x18\x1e \x01(\t\x12\'\n\x1fnetwork_acl_bypass_resource_ids\x18\x1f \x03(\t\x12\x1d\n\x15public_network_access\x18  \x01(\t\x12U\n\x12restore_parameters\x18! \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_documentdb.RestoreParameters\x12Y\n\x15virtual_network_rules\x18\" \x03(\x0b\x32:.oak9.tython.azure.microsoft_documentdb.VirtualNetworkRule\x12P\n\x04tags\x18# \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_documentdb.DatabaseAccounts.TagsEntry\x12`\n\x18\x64\x61tabase_accounts_graphs\x18$ \x03(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsGraphs\x12z\n&database_accounts_sql_role_definitions\x18% \x03(\x0b\x32J.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlRoleDefinitions\x12z\n&database_accounts_sql_role_assignments\x18& \x03(\x0b\x32J.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsSqlRoleAssignments\x12u\n#database_accounts_mongodb_databases\x18\' \x03(\x0b\x32H.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsMongodbDatabases\x12\x82\x01\n*database_accounts_mongodb_role_definitions\x18( \x03(\x0b\x32N.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsMongodbRoleDefinitions\x12\x82\x01\n*database_accounts_mongodb_user_definitions\x18) \x03(\x0b\x32N.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsMongodbUserDefinitions\x12`\n\x18\x64\x61tabase_accounts_tables\x18* \x03(\x0b\x32>.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsTables\x12u\n#database_accounts_gremlin_databases\x18+ \x03(\x0b\x32H.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsGremlinDatabases\x12v\n$database_accounts_data_transfer_jobs\x18, \x03(\x0b\x32H.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsDataTransferJobs\x12y\n%database_accounts_notebook_workspaces\x18- \x03(\x0b\x32J.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsNotebookWorkspaces\x12\x8a\x01\n.database_accounts_private_endpoint_connections\x18. \x03(\x0b\x32R.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsPrivateEndpointConnections\x12\x64\n\x1a\x64\x61tabase_accounts_services\x18/ \x03(\x0b\x32@.oak9.tython.azure.microsoft_documentdb.DatabaseAccountsServices\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"O\n\x12VirtualNetworkRule\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n%ignore_missing_v_net_service_endpoint\x18\x02 \x01(\x08\"\xcb\x02\n\x11RestoreParameters\x12]\n\x14\x64\x61tabases_to_restore\x18\x01 \x03(\x0b\x32?.oak9.tython.azure.microsoft_documentdb.DatabaseRestoreResource\x12l\n\x1cgremlin_databases_to_restore\x18\x02 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_documentdb.GremlinDatabaseRestoreResource\x12\x14\n\x0crestore_mode\x18\x03 \x01(\t\x12\x16\n\x0erestore_source\x18\x04 \x01(\t\x12 \n\x18restore_timestamp_in_utc\x18\x05 \x01(\t\x12\x19\n\x11tables_to_restore\x18\x06 \x03(\t\"L\n\x1eGremlinDatabaseRestoreResource\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\x12\x13\n\x0bgraph_names\x18\x02 \x03(\t\"J\n\x17\x44\x61tabaseRestoreResource\x12\x18\n\x10\x63ollection_names\x18\x01 \x03(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"s\n\x08Location\x12\x19\n\x11\x66\x61ilover_priority\x18\x01 \x01(\x05\x12\x19\n\x11is_zone_redundant\x18\x02 \x01(\x08\x12\x15\n\rlocation_name\x18\x03 \x01(\t\x12\x1a\n\x12provisioning_state\x18\x04 \x01(\t\"/\n\x10IpAddressOrRange\x12\x1b\n\x13ip_address_or_range\x18\x01 \x01(\t\"7\n\x15\x44iagnosticLogSettings\x12\x1e\n\x16\x65nable_full_text_query\x18\x01 \x01(\t\"\x8c\x01\n\nCorsPolicy\x12\x17\n\x0f\x61llowed_headers\x18\x01 \x01(\t\x12\x17\n\x0f\x61llowed_methods\x18\x02 \x01(\t\x12\x17\n\x0f\x61llowed_origins\x18\x03 \x01(\t\x12\x17\n\x0f\x65xposed_headers\x18\x04 \x01(\t\x12\x1a\n\x12max_age_in_seconds\x18\x05 \x01(\x05\"u\n\x11\x43onsistencyPolicy\x12!\n\x19\x64\x65\x66\x61ult_consistency_level\x18\x01 \x01(\t\x12\x1f\n\x17max_interval_in_seconds\x18\x02 \x01(\x05\x12\x1c\n\x14max_staleness_prefix\x18\x03 \x01(\x05\"*\n\x08\x43\x61pacity\x12\x1e\n\x16total_throughput_limit\x18\x01 \x01(\x05\"\x1a\n\nCapability\x12\x0c\n\x04name\x18\x01 \x01(\t\"k\n\x0c\x42\x61\x63kupPolicy\x12[\n\x0fmigration_state\x18\x01 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_documentdb.BackupPolicyMigrationState\"U\n\x1a\x42\x61\x63kupPolicyMigrationState\x12\x12\n\nstart_time\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x13\n\x0btarget_type\x18\x03 \x01(\t\"\'\n\rApiProperties\x12\x16\n\x0eserver_version\x18\x01 \x01(\t\"5\n\x1e\x41nalyticalStorageConfiguration\x12\x13\n\x0bschema_type\x18\x01 \x01(\t\"\xe3\x01\n\x16ManagedServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12|\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_documentdb.ManagedServiceIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x04\n\x1c\x43\x61ssandraClustersDataCenters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12y\n%authentication_method_ldap_properties\x18\x03 \x01(\x0b\x32J.oak9.tython.azure.microsoft_documentdb.AuthenticationMethodLdapProperties\x12\x19\n\x11\x61vailability_zone\x18\x04 \x01(\x08\x12\'\n\x1f\x62\x61\x63kup_storage_customer_key_uri\x18\x05 \x01(\t\x12.\n&base64_encoded_cassandra_yaml_fragment\x18\x06 \x01(\t\x12\x1c\n\x14\x64\x61ta_center_location\x18\x07 \x01(\t\x12\x1b\n\x13\x64\x65legated_subnet_id\x18\x08 \x01(\t\x12\x15\n\rdisk_capacity\x18\t \x01(\x05\x12\x10\n\x08\x64isk_sku\x18\n \x01(\t\x12%\n\x1dmanaged_disk_customer_key_uri\x18\x0b \x01(\t\x12\x12\n\nnode_count\x18\x0c \x01(\x05\x12\x1a\n\x12provisioning_state\x18\r \x01(\t\x12\x0b\n\x03sku\x18\x0e \x01(\t\"\xb4\x02\n\"AuthenticationMethodLdapProperties\x12&\n\x1esearch_base_distinguished_name\x18\x01 \x01(\t\x12\x1e\n\x16search_filter_template\x18\x02 \x01(\t\x12P\n\x13server_certificates\x18\x03 \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_documentdb.Certificate\x12\x17\n\x0fserver_hostname\x18\x04 \x01(\t\x12\x13\n\x0bserver_port\x18\x05 \x01(\x05\x12\'\n\x1fservice_user_distinguished_name\x18\x06 \x01(\t\x12\x1d\n\x15service_user_password\x18\x07 \x01(\t\"\xe4\x08\n\x11\x43\x61ssandraClusters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12`\n\x08identity\x18\x02 \x01(\x0b\x32N.oak9.tython.azure.microsoft_documentdb.ManagedCassandraManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1d\n\x15\x61uthentication_method\x18\x05 \x01(\t\x12\'\n\x1f\x63\x61ssandra_audit_logging_enabled\x18\x06 \x01(\x08\x12\x19\n\x11\x63\x61ssandra_version\x18\x07 \x01(\t\x12P\n\x13\x63lient_certificates\x18\x08 \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_documentdb.Certificate\x12\x1d\n\x15\x63luster_name_override\x18\t \x01(\t\x12\x13\n\x0b\x64\x65\x61llocated\x18\n \x01(\x08\x12&\n\x1e\x64\x65legated_management_subnet_id\x18\x0b \x01(\t\x12Y\n\x1c\x65xternal_gossip_certificates\x18\x0c \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_documentdb.Certificate\x12M\n\x13\x65xternal_seed_nodes\x18\r \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_documentdb.SeedNode\x12\x1d\n\x15hours_between_backups\x18\x0e \x01(\x05\x12(\n initial_cassandra_admin_password\x18\x0f \x01(\t\x12M\n\x13prometheus_endpoint\x18\x10 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_documentdb.SeedNode\x12\x1a\n\x12provisioning_state\x18\x11 \x01(\t\x12\x16\n\x0erepair_enabled\x18\x12 \x01(\x08\x12\x1e\n\x16restore_from_backup_id\x18\x13 \x01(\t\x12Q\n\x04tags\x18\x14 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_documentdb.CassandraClusters.TagsEntry\x12m\n\x1f\x63\x61ssandra_clusters_data_centers\x18\x15 \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_documentdb.CassandraClustersDataCenters\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1e\n\x08SeedNode\x12\x12\n\nip_address\x18\x01 \x01(\t\"\x1a\n\x0b\x43\x65rtificate\x12\x0b\n\x03pem\x18\x01 \x01(\t\"6\n&ManagedCassandraManagedServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_documentdb_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATABASEACCOUNTSTABLESTHROUGHPUTSETTINGS_TAGSENTRY._options = None
  _DATABASEACCOUNTSTABLESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSTABLES_TAGSENTRY._options = None
  _DATABASEACCOUNTSTABLES_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSSQLDATABASESTHROUGHPUTSETTINGS_TAGSENTRY._options = None
  _DATABASEACCOUNTSSQLDATABASESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSUSERDEFINEDFUNCTIONS_TAGSENTRY._options = None
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSUSERDEFINEDFUNCTIONS_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSTRIGGERS_TAGSENTRY._options = None
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSTRIGGERS_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSTHROUGHPUTSETTINGS_TAGSENTRY._options = None
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSTHROUGHPUTSETTINGS_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSSTOREDPROCEDURES_TAGSENTRY._options = None
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSSTOREDPROCEDURES_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSSQLDATABASESCONTAINERS_TAGSENTRY._options = None
  _DATABASEACCOUNTSSQLDATABASESCONTAINERS_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSSQLDATABASES_TAGSENTRY._options = None
  _DATABASEACCOUNTSSQLDATABASES_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSMONGODBDATABASESTHROUGHPUTSETTINGS_TAGSENTRY._options = None
  _DATABASEACCOUNTSMONGODBDATABASESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSMONGODBDATABASESCOLLECTIONSTHROUGHPUTSETTINGS_TAGSENTRY._options = None
  _DATABASEACCOUNTSMONGODBDATABASESCOLLECTIONSTHROUGHPUTSETTINGS_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSMONGODBDATABASESCOLLECTIONS_TAGSENTRY._options = None
  _DATABASEACCOUNTSMONGODBDATABASESCOLLECTIONS_TAGSENTRY._serialized_options = b'8\001'
  _MONGODBCOLLECTIONRESOURCE_SHARDKEYENTRY._options = None
  _MONGODBCOLLECTIONRESOURCE_SHARDKEYENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSMONGODBDATABASES_TAGSENTRY._options = None
  _DATABASEACCOUNTSMONGODBDATABASES_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSGREMLINDATABASESTHROUGHPUTSETTINGS_TAGSENTRY._options = None
  _DATABASEACCOUNTSGREMLINDATABASESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSGREMLINDATABASESGRAPHSTHROUGHPUTSETTINGS_TAGSENTRY._options = None
  _DATABASEACCOUNTSGREMLINDATABASESGRAPHSTHROUGHPUTSETTINGS_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSGREMLINDATABASESGRAPHS_TAGSENTRY._options = None
  _DATABASEACCOUNTSGREMLINDATABASESGRAPHS_TAGSENTRY._serialized_options = b'8\001'
  _INDEXINGPOLICY_COMPOSITEINDEXESENTRY._options = None
  _INDEXINGPOLICY_COMPOSITEINDEXESENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSGREMLINDATABASES_TAGSENTRY._options = None
  _DATABASEACCOUNTSGREMLINDATABASES_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSGRAPHS_TAGSENTRY._options = None
  _DATABASEACCOUNTSGRAPHS_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSCASSANDRAKEYSPACESVIEWSTHROUGHPUTSETTINGS_TAGSENTRY._options = None
  _DATABASEACCOUNTSCASSANDRAKEYSPACESVIEWSTHROUGHPUTSETTINGS_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSCASSANDRAKEYSPACESVIEWS_TAGSENTRY._options = None
  _DATABASEACCOUNTSCASSANDRAKEYSPACESVIEWS_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTHROUGHPUTSETTINGS_TAGSENTRY._options = None
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTABLESTHROUGHPUTSETTINGS_TAGSENTRY._options = None
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTABLESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTABLES_TAGSENTRY._options = None
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTABLES_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTSCASSANDRAKEYSPACES_TAGSENTRY._options = None
  _DATABASEACCOUNTSCASSANDRAKEYSPACES_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEACCOUNTS_TAGSENTRY._options = None
  _DATABASEACCOUNTS_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _CASSANDRACLUSTERS_TAGSENTRY._options = None
  _CASSANDRACLUSTERS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_DOCUMENTDB._serialized_start=104
  _MICROSOFT_DOCUMENTDB._serialized_end=1015
  _DATABASEACCOUNTSTABLESTHROUGHPUTSETTINGS._serialized_start=1018
  _DATABASEACCOUNTSTABLESTHROUGHPUTSETTINGS._serialized_end=1468
  _DATABASEACCOUNTSTABLESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSTABLESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_end=1468
  _DATABASEACCOUNTSTABLES._serialized_start=1471
  _DATABASEACCOUNTSTABLES._serialized_end=2087
  _DATABASEACCOUNTSTABLES_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSTABLES_TAGSENTRY._serialized_end=1468
  _TABLERESOURCE._serialized_start=2089
  _TABLERESOURCE._serialized_end=2116
  _DATABASEACCOUNTSSQLROLEDEFINITIONS._serialized_start=2119
  _DATABASEACCOUNTSSQLROLEDEFINITIONS._serialized_end=2359
  _PERMISSION._serialized_start=2361
  _PERMISSION._serialized_end=2421
  _DATABASEACCOUNTSSQLROLEASSIGNMENTS._serialized_start=2424
  _DATABASEACCOUNTSSQLROLEASSIGNMENTS._serialized_end=2596
  _DATABASEACCOUNTSSQLDATABASESTHROUGHPUTSETTINGS._serialized_start=2599
  _DATABASEACCOUNTSSQLDATABASESTHROUGHPUTSETTINGS._serialized_end=3061
  _DATABASEACCOUNTSSQLDATABASESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSSQLDATABASESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_end=1468
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSUSERDEFINEDFUNCTIONS._serialized_start=3064
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSUSERDEFINEDFUNCTIONS._serialized_end=3632
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSUSERDEFINEDFUNCTIONS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSUSERDEFINEDFUNCTIONS_TAGSENTRY._serialized_end=1468
  _SQLUSERDEFINEDFUNCTIONRESOURCE._serialized_start=3634
  _SQLUSERDEFINEDFUNCTIONRESOURCE._serialized_end=3692
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSTRIGGERS._serialized_start=3695
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSTRIGGERS._serialized_end=4227
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSTRIGGERS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSTRIGGERS_TAGSENTRY._serialized_end=1468
  _SQLTRIGGERRESOURCE._serialized_start=4229
  _SQLTRIGGERRESOURCE._serialized_end=4324
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSTHROUGHPUTSETTINGS._serialized_start=4327
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSTHROUGHPUTSETTINGS._serialized_end=4809
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSTHROUGHPUTSETTINGS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSTHROUGHPUTSETTINGS_TAGSENTRY._serialized_end=1468
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSSTOREDPROCEDURES._serialized_start=4812
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSSTOREDPROCEDURES._serialized_end=5368
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSSTOREDPROCEDURES_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSSQLDATABASESCONTAINERSSTOREDPROCEDURES_TAGSENTRY._serialized_end=1468
  _SQLSTOREDPROCEDURERESOURCE._serialized_start=5370
  _SQLSTOREDPROCEDURERESOURCE._serialized_end=5424
  _DATABASEACCOUNTSSQLDATABASESCONTAINERS._serialized_start=5427
  _DATABASEACCOUNTSSQLDATABASESCONTAINERS._serialized_end=6442
  _DATABASEACCOUNTSSQLDATABASESCONTAINERS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSSQLDATABASESCONTAINERS_TAGSENTRY._serialized_end=1468
  _SQLCONTAINERRESOURCE._serialized_start=6445
  _SQLCONTAINERRESOURCE._serialized_end=6885
  _DATABASEACCOUNTSSQLDATABASESCLIENTENCRYPTIONKEYS._serialized_start=6888
  _DATABASEACCOUNTSSQLDATABASESCLIENTENCRYPTIONKEYS._serialized_end=7096
  _CLIENTENCRYPTIONKEYRESOURCE._serialized_start=7099
  _CLIENTENCRYPTIONKEYRESOURCE._serialized_end=7291
  _KEYWRAPMETADATA._serialized_start=7293
  _KEYWRAPMETADATA._serialized_end=7372
  _DATABASEACCOUNTSSQLDATABASES._serialized_start=7375
  _DATABASEACCOUNTSSQLDATABASES._serialized_end=8177
  _DATABASEACCOUNTSSQLDATABASES_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSSQLDATABASES_TAGSENTRY._serialized_end=1468
  _SQLDATABASERESOURCE._serialized_start=8179
  _SQLDATABASERESOURCE._serialized_end=8212
  _DATABASEACCOUNTSSERVICES._serialized_start=8215
  _DATABASEACCOUNTSSERVICES._serialized_end=8381
  _DATABASEACCOUNTSPRIVATEENDPOINTCONNECTIONS._serialized_start=8384
  _DATABASEACCOUNTSPRIVATEENDPOINTCONNECTIONS._serialized_end=8767
  _PRIVATELINKSERVICECONNECTIONSTATEPROPERTY._serialized_start=8769
  _PRIVATELINKSERVICECONNECTIONSTATEPROPERTY._serialized_end=8849
  _PRIVATEENDPOINTPROPERTY._serialized_start=8851
  _PRIVATEENDPOINTPROPERTY._serialized_end=8888
  _DATABASEACCOUNTSNOTEBOOKWORKSPACES._serialized_start=8890
  _DATABASEACCOUNTSNOTEBOOKWORKSPACES._serialized_end=8997
  _DATABASEACCOUNTSMONGODBUSERDEFINITIONS._serialized_start=9000
  _DATABASEACCOUNTSMONGODBUSERDEFINITIONS._serialized_end=9273
  _DATABASEACCOUNTSMONGODBROLEDEFINITIONS._serialized_start=9276
  _DATABASEACCOUNTSMONGODBROLEDEFINITIONS._serialized_end=9575
  _ROLE._serialized_start=9577
  _ROLE._serialized_end=9609
  _PRIVILEGE._serialized_start=9611
  _PRIVILEGE._serialized_end=9716
  _PRIVILEGERESOURCE._serialized_start=9718
  _PRIVILEGERESOURCE._serialized_end=9769
  _DATABASEACCOUNTSMONGODBDATABASESTHROUGHPUTSETTINGS._serialized_start=9772
  _DATABASEACCOUNTSMONGODBDATABASESTHROUGHPUTSETTINGS._serialized_end=10242
  _DATABASEACCOUNTSMONGODBDATABASESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSMONGODBDATABASESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_end=1468
  _DATABASEACCOUNTSMONGODBDATABASESCOLLECTIONSTHROUGHPUTSETTINGS._serialized_start=10245
  _DATABASEACCOUNTSMONGODBDATABASESCOLLECTIONSTHROUGHPUTSETTINGS._serialized_end=10737
  _DATABASEACCOUNTSMONGODBDATABASESCOLLECTIONSTHROUGHPUTSETTINGS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSMONGODBDATABASESCOLLECTIONSTHROUGHPUTSETTINGS_TAGSENTRY._serialized_end=1468
  _DATABASEACCOUNTSMONGODBDATABASESCOLLECTIONS._serialized_start=10740
  _DATABASEACCOUNTSMONGODBDATABASESCOLLECTIONS._serialized_end=11454
  _DATABASEACCOUNTSMONGODBDATABASESCOLLECTIONS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSMONGODBDATABASESCOLLECTIONS_TAGSENTRY._serialized_end=1468
  _MONGODBCOLLECTIONRESOURCE._serialized_start=11457
  _MONGODBCOLLECTIONRESOURCE._serialized_end=11746
  _MONGODBCOLLECTIONRESOURCE_SHARDKEYENTRY._serialized_start=11699
  _MONGODBCOLLECTIONRESOURCE_SHARDKEYENTRY._serialized_end=11746
  _MONGOINDEX._serialized_start=11749
  _MONGOINDEX._serialized_end=11906
  _MONGOINDEXOPTIONS._serialized_start=11908
  _MONGOINDEXOPTIONS._serialized_end=11973
  _MONGOINDEXKEYS._serialized_start=11975
  _MONGOINDEXKEYS._serialized_end=12005
  _DATABASEACCOUNTSMONGODBDATABASES._serialized_start=12008
  _DATABASEACCOUNTSMONGODBDATABASES._serialized_end=12818
  _DATABASEACCOUNTSMONGODBDATABASES_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSMONGODBDATABASES_TAGSENTRY._serialized_end=1468
  _MONGODBDATABASERESOURCE._serialized_start=12820
  _MONGODBDATABASERESOURCE._serialized_end=12857
  _DATABASEACCOUNTSGREMLINDATABASESTHROUGHPUTSETTINGS._serialized_start=12860
  _DATABASEACCOUNTSGREMLINDATABASESTHROUGHPUTSETTINGS._serialized_end=13330
  _DATABASEACCOUNTSGREMLINDATABASESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSGREMLINDATABASESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_end=1468
  _DATABASEACCOUNTSGREMLINDATABASESGRAPHSTHROUGHPUTSETTINGS._serialized_start=13333
  _DATABASEACCOUNTSGREMLINDATABASESGRAPHSTHROUGHPUTSETTINGS._serialized_end=13815
  _DATABASEACCOUNTSGREMLINDATABASESGRAPHSTHROUGHPUTSETTINGS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSGREMLINDATABASESGRAPHSTHROUGHPUTSETTINGS_TAGSENTRY._serialized_end=1468
  _DATABASEACCOUNTSGREMLINDATABASESGRAPHS._serialized_start=13818
  _DATABASEACCOUNTSGREMLINDATABASESGRAPHS._serialized_end=14507
  _DATABASEACCOUNTSGREMLINDATABASESGRAPHS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSGREMLINDATABASESGRAPHS_TAGSENTRY._serialized_end=1468
  _GREMLINGRAPHRESOURCE._serialized_start=14510
  _GREMLINGRAPHRESOURCE._serialized_end=14918
  _UNIQUEKEYPOLICY._serialized_start=14920
  _UNIQUEKEYPOLICY._serialized_end=15009
  _UNIQUEKEY._serialized_start=15011
  _UNIQUEKEY._serialized_end=15037
  _CONTAINERPARTITIONKEY._serialized_start=15039
  _CONTAINERPARTITIONKEY._serialized_end=15108
  _INDEXINGPOLICY._serialized_start=15111
  _INDEXINGPOLICY._serialized_end=15565
  _INDEXINGPOLICY_COMPOSITEINDEXESENTRY._serialized_start=15510
  _INDEXINGPOLICY_COMPOSITEINDEXESENTRY._serialized_end=15565
  _SPATIALSPEC._serialized_start=15567
  _SPATIALSPEC._serialized_end=15609
  _INCLUDEDPATH._serialized_start=15611
  _INCLUDEDPATH._serialized_end=15705
  _INDEXES._serialized_start=15707
  _INDEXES._serialized_end=15768
  _EXCLUDEDPATH._serialized_start=15770
  _EXCLUDEDPATH._serialized_end=15798
  _CONFLICTRESOLUTIONPOLICY._serialized_start=15800
  _CONFLICTRESOLUTIONPOLICY._serialized_end=15913
  _DATABASEACCOUNTSGREMLINDATABASES._serialized_start=15916
  _DATABASEACCOUNTSGREMLINDATABASES._serialized_end=16583
  _DATABASEACCOUNTSGREMLINDATABASES_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSGREMLINDATABASES_TAGSENTRY._serialized_end=1468
  _GREMLINDATABASERESOURCE._serialized_start=16585
  _GREMLINDATABASERESOURCE._serialized_end=16622
  _DATABASEACCOUNTSGRAPHS._serialized_start=16625
  _DATABASEACCOUNTSGRAPHS._serialized_end=17104
  _DATABASEACCOUNTSGRAPHS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSGRAPHS_TAGSENTRY._serialized_end=1468
  _GRAPHRESOURCE._serialized_start=17106
  _GRAPHRESOURCE._serialized_end=17133
  _DATABASEACCOUNTSDATATRANSFERJOBS._serialized_start=17136
  _DATABASEACCOUNTSDATATRANSFERJOBS._serialized_end=17436
  _DATATRANSFERDATASOURCESINK._serialized_start=17438
  _DATATRANSFERDATASOURCESINK._serialized_end=17480
  _DATABASEACCOUNTSCASSANDRAKEYSPACESVIEWSTHROUGHPUTSETTINGS._serialized_start=17483
  _DATABASEACCOUNTSCASSANDRAKEYSPACESVIEWSTHROUGHPUTSETTINGS._serialized_end=17967
  _DATABASEACCOUNTSCASSANDRAKEYSPACESVIEWSTHROUGHPUTSETTINGS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSCASSANDRAKEYSPACESVIEWSTHROUGHPUTSETTINGS_TAGSENTRY._serialized_end=1468
  _DATABASEACCOUNTSCASSANDRAKEYSPACESVIEWS._serialized_start=17970
  _DATABASEACCOUNTSCASSANDRAKEYSPACESVIEWS._serialized_end=18664
  _DATABASEACCOUNTSCASSANDRAKEYSPACESVIEWS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSCASSANDRAKEYSPACESVIEWS_TAGSENTRY._serialized_end=1468
  _CASSANDRAVIEWRESOURCE._serialized_start=18666
  _CASSANDRAVIEWRESOURCE._serialized_end=18726
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTHROUGHPUTSETTINGS._serialized_start=18729
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTHROUGHPUTSETTINGS._serialized_end=19203
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_end=1468
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTABLESTHROUGHPUTSETTINGS._serialized_start=19206
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTABLESTHROUGHPUTSETTINGS._serialized_end=19692
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTABLESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTABLESTHROUGHPUTSETTINGS_TAGSENTRY._serialized_end=1468
  _THROUGHPUTSETTINGSRESOURCE._serialized_start=19695
  _THROUGHPUTSETTINGSRESOURCE._serialized_end=19838
  _AUTOSCALESETTINGSRESOURCE._serialized_start=19841
  _AUTOSCALESETTINGSRESOURCE._serialized_end=19988
  _AUTOUPGRADEPOLICYRESOURCE._serialized_start=19990
  _AUTOUPGRADEPOLICYRESOURCE._serialized_end=20110
  _THROUGHPUTPOLICYRESOURCE._serialized_start=20112
  _THROUGHPUTPOLICYRESOURCE._serialized_end=20185
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTABLES._serialized_start=20188
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTABLES._serialized_end=20887
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTABLES_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSCASSANDRAKEYSPACESTABLES_TAGSENTRY._serialized_end=1468
  _CASSANDRATABLERESOURCE._serialized_start=20890
  _CASSANDRATABLERESOURCE._serialized_end=21052
  _CASSANDRASCHEMA._serialized_start=21055
  _CASSANDRASCHEMA._serialized_end=21298
  _CASSANDRAPARTITIONKEY._serialized_start=21300
  _CASSANDRAPARTITIONKEY._serialized_end=21337
  _COLUMN._serialized_start=21339
  _COLUMN._serialized_end=21375
  _CLUSTERKEY._serialized_start=21377
  _CLUSTERKEY._serialized_end=21421
  _DATABASEACCOUNTSCASSANDRAKEYSPACES._serialized_start=21424
  _DATABASEACCOUNTSCASSANDRAKEYSPACES._serialized_end=22236
  _DATABASEACCOUNTSCASSANDRAKEYSPACES_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTSCASSANDRAKEYSPACES_TAGSENTRY._serialized_end=1468
  _CASSANDRAKEYSPACERESOURCE._serialized_start=22238
  _CASSANDRAKEYSPACERESOURCE._serialized_end=22277
  _CREATEUPDATEOPTIONS._serialized_start=22280
  _CREATEUPDATEOPTIONS._serialized_end=22408
  _AUTOSCALESETTINGS._serialized_start=22410
  _AUTOSCALESETTINGS._serialized_end=22453
  _DATABASEACCOUNTS._serialized_start=22456
  _DATABASEACCOUNTS._serialized_end=25768
  _DATABASEACCOUNTS_TAGSENTRY._serialized_start=1425
  _DATABASEACCOUNTS_TAGSENTRY._serialized_end=1468
  _VIRTUALNETWORKRULE._serialized_start=25770
  _VIRTUALNETWORKRULE._serialized_end=25849
  _RESTOREPARAMETERS._serialized_start=25852
  _RESTOREPARAMETERS._serialized_end=26183
  _GREMLINDATABASERESTORERESOURCE._serialized_start=26185
  _GREMLINDATABASERESTORERESOURCE._serialized_end=26261
  _DATABASERESTORERESOURCE._serialized_start=26263
  _DATABASERESTORERESOURCE._serialized_end=26337
  _LOCATION._serialized_start=26339
  _LOCATION._serialized_end=26454
  _IPADDRESSORRANGE._serialized_start=26456
  _IPADDRESSORRANGE._serialized_end=26503
  _DIAGNOSTICLOGSETTINGS._serialized_start=26505
  _DIAGNOSTICLOGSETTINGS._serialized_end=26560
  _CORSPOLICY._serialized_start=26563
  _CORSPOLICY._serialized_end=26703
  _CONSISTENCYPOLICY._serialized_start=26705
  _CONSISTENCYPOLICY._serialized_end=26822
  _CAPACITY._serialized_start=26824
  _CAPACITY._serialized_end=26866
  _CAPABILITY._serialized_start=26868
  _CAPABILITY._serialized_end=26894
  _BACKUPPOLICY._serialized_start=26896
  _BACKUPPOLICY._serialized_end=27003
  _BACKUPPOLICYMIGRATIONSTATE._serialized_start=27005
  _BACKUPPOLICYMIGRATIONSTATE._serialized_end=27090
  _APIPROPERTIES._serialized_start=27092
  _APIPROPERTIES._serialized_end=27131
  _ANALYTICALSTORAGECONFIGURATION._serialized_start=27133
  _ANALYTICALSTORAGECONFIGURATION._serialized_end=27186
  _MANAGEDSERVICEIDENTITY._serialized_start=27189
  _MANAGEDSERVICEIDENTITY._serialized_end=27416
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=27355
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=27416
  _CASSANDRACLUSTERSDATACENTERS._serialized_start=27419
  _CASSANDRACLUSTERSDATACENTERS._serialized_end=27959
  _AUTHENTICATIONMETHODLDAPPROPERTIES._serialized_start=27962
  _AUTHENTICATIONMETHODLDAPPROPERTIES._serialized_end=28270
  _CASSANDRACLUSTERS._serialized_start=28273
  _CASSANDRACLUSTERS._serialized_end=29397
  _CASSANDRACLUSTERS_TAGSENTRY._serialized_start=1425
  _CASSANDRACLUSTERS_TAGSENTRY._serialized_end=1468
  _SEEDNODE._serialized_start=29399
  _SEEDNODE._serialized_end=29429
  _CERTIFICATE._serialized_start=29431
  _CERTIFICATE._serialized_end=29457
  _MANAGEDCASSANDRAMANAGEDSERVICEIDENTITY._serialized_start=29459
  _MANAGEDCASSANDRAMANAGEDSERVICEIDENTITY._serialized_end=29513
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_secret.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14gcp/gcp_secret.proto\x12\x16oak9.tython.gcp.secret\x1a\x13shared/shared.proto\"f\nNSecretManagerSecretXReplicationXUserManagedXReplicasXCustomerManagedEncryption\x12\x14\n\x0ckms_key_name\x18\x01 \x01(\t\"\xd6\x01\n4SecretManagerSecretXReplicationXUserManagedXReplicas\x12\x10\n\x08location\x18\x01 \x01(\t\x12\x8b\x01\n\x1b\x63ustomer_managed_encryption\x18\x02 \x01(\x0b\x32\x66.oak9.tython.gcp.secret.SecretManagerSecretXReplicationXUserManagedXReplicasXCustomerManagedEncryption\"\x8d\x01\n+SecretManagerSecretXReplicationXUserManaged\x12^\n\x08replicas\x18\x01 \x03(\x0b\x32L.oak9.tython.gcp.secret.SecretManagerSecretXReplicationXUserManagedXReplicas\"\x8f\x01\n\x1fSecretManagerSecretXReplication\x12\x11\n\tautomatic\x18\x01 \x01(\x08\x12Y\n\x0cuser_managed\x18\x02 \x01(\x0b\x32\x43.oak9.tython.gcp.secret.SecretManagerSecretXReplicationXUserManaged\"S\n\x1cSecretManagerSecretXRotation\x12\x1a\n\x12next_rotation_time\x18\x01 \x01(\t\x12\x17\n\x0frotation_period\x18\x02 \x01(\t\"N\n\x1cSecretManagerSecretXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"*\n\x1aSecretManagerSecretXTopics\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xdd\x04\n\x13SecretManagerSecret\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x65xpire_time\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12G\n\x06labels\x18\x04 \x03(\x0b\x32\x37.oak9.tython.gcp.secret.SecretManagerSecret.LabelsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x11\n\tsecret_id\x18\x07 \x01(\t\x12\x0b\n\x03ttl\x18\x08 \x01(\t\x12L\n\x0breplication\x18\t \x01(\x0b\x32\x37.oak9.tython.gcp.secret.SecretManagerSecretXReplication\x12\x46\n\x08rotation\x18\n \x01(\x0b\x32\x34.oak9.tython.gcp.secret.SecretManagerSecretXRotation\x12\x46\n\x08timeouts\x18\x0b \x01(\x0b\x32\x34.oak9.tython.gcp.secret.SecretManagerSecretXTimeouts\x12\x42\n\x06topics\x18\x0c \x03(\x0b\x32\x32.oak9.tython.gcp.secret.SecretManagerSecretXTopics\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n\'SecretManagerSecretIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x89\x02\n\x1dSecretManagerSecretIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x11\n\tsecret_id\x18\x06 \x01(\t\x12R\n\tcondition\x18\x07 \x01(\x0b\x32?.oak9.tython.gcp.secret.SecretManagerSecretIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"`\n&SecretManagerSecretIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x86\x02\n\x1cSecretManagerSecretIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x11\n\tsecret_id\x18\x06 \x01(\t\x12Q\n\tcondition\x18\x07 \x01(\x0b\x32>.oak9.tython.gcp.secret.SecretManagerSecretIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xaa\x01\n\x1cSecretManagerSecretIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x11\n\tsecret_id\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"E\n#SecretManagerSecretVersionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x9f\x02\n\x1aSecretManagerSecretVersion\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65stroy_time\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0e\n\x06secret\x18\x06 \x01(\t\x12\x13\n\x0bsecret_data\x18\x07 \x01(\t\x12M\n\x08timeouts\x18\x08 \x01(\x0b\x32;.oak9.tython.gcp.secret.SecretManagerSecretVersionXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_secret_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SECRETMANAGERSECRET_LABELSENTRY._options = None
  _SECRETMANAGERSECRET_LABELSENTRY._serialized_options = b'8\001'
  _SECRETMANAGERSECRETXREPLICATIONXUSERMANAGEDXREPLICASXCUSTOMERMANAGEDENCRYPTION._serialized_start=69
  _SECRETMANAGERSECRETXREPLICATIONXUSERMANAGEDXREPLICASXCUSTOMERMANAGEDENCRYPTION._serialized_end=171
  _SECRETMANAGERSECRETXREPLICATIONXUSERMANAGEDXREPLICAS._serialized_start=174
  _SECRETMANAGERSECRETXREPLICATIONXUSERMANAGEDXREPLICAS._serialized_end=388
  _SECRETMANAGERSECRETXREPLICATIONXUSERMANAGED._serialized_start=391
  _SECRETMANAGERSECRETXREPLICATIONXUSERMANAGED._serialized_end=532
  _SECRETMANAGERSECRETXREPLICATION._serialized_start=535
  _SECRETMANAGERSECRETXREPLICATION._serialized_end=678
  _SECRETMANAGERSECRETXROTATION._serialized_start=680
  _SECRETMANAGERSECRETXROTATION._serialized_end=763
  _SECRETMANAGERSECRETXTIMEOUTS._serialized_start=765
  _SECRETMANAGERSECRETXTIMEOUTS._serialized_end=843
  _SECRETMANAGERSECRETXTOPICS._serialized_start=845
  _SECRETMANAGERSECRETXTOPICS._serialized_end=887
  _SECRETMANAGERSECRET._serialized_start=890
  _SECRETMANAGERSECRET._serialized_end=1495
  _SECRETMANAGERSECRET_LABELSENTRY._serialized_start=1450
  _SECRETMANAGERSECRET_LABELSENTRY._serialized_end=1495
  _SECRETMANAGERSECRETIAMBINDINGXCONDITION._serialized_start=1497
  _SECRETMANAGERSECRETIAMBINDINGXCONDITION._serialized_end=1594
  _SECRETMANAGERSECRETIAMBINDING._serialized_start=1597
  _SECRETMANAGERSECRETIAMBINDING._serialized_end=1862
  _SECRETMANAGERSECRETIAMMEMBERXCONDITION._serialized_start=1864
  _SECRETMANAGERSECRETIAMMEMBERXCONDITION._serialized_end=1960
  _SECRETMANAGERSECRETIAMMEMBER._serialized_start=1963
  _SECRETMANAGERSECRETIAMMEMBER._serialized_end=2225
  _SECRETMANAGERSECRETIAMPOLICY._serialized_start=2228
  _SECRETMANAGERSECRETIAMPOLICY._serialized_end=2398
  _SECRETMANAGERSECRETVERSIONXTIMEOUTS._serialized_start=2400
  _SECRETMANAGERSECRETVERSIONXTIMEOUTS._serialized_end=2469
  _SECRETMANAGERSECRETVERSION._serialized_start=2472
  _SECRETMANAGERSECRETVERSION._serialized_end=2759
# @@protoc_insertion_point(module_scope)
